#
# spec file for package waycheck
#
# Copyright (c) Neal Gompa
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global qt6_minver 6.5

Name:           waycheck
Version:        1.6.0
Release:        1.2
Summary:        GUI that displays protocols implemented by a Wayland compositor

License:        Apache-2.0
URL:            https://gitlab.freedesktop.org/serebit/waycheck
Source0:        %{url}/-/archive/v%{version}/%{name}-v%{version}.tar.gz

BuildRequires:  meson
%if 0%{?suse_version} && 0%{?suse_version} < 1600
BuildRequires:  gcc11-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  pkgconfig(Qt6Core) >= %{qt6_minver}
BuildRequires:  pkgconfig(Qt6Gui) >= %{qt6_minver}
BuildRequires:  pkgconfig(Qt6WaylandClient) >= %{qt6_minver}
BuildRequires:  pkgconfig(Qt6Widgets) >= %{qt6_minver}
BuildRequires:  pkgconfig(wayland-client)

Requires:       hicolor-icon-theme

%description
%{summary}.

%prep
%autosetup -n %{name}-v%{version}


%build
%if 0%{?suse_version} && 0%{?suse_version} < 1600
export CC=gcc-11
export CXX=g++-11
%endif
%meson
%meson_build


%install
%meson_install


%files
%license LICENSES/*
%doc README.md
%{_bindir}/waycheck
%{_datadir}/applications/dev.serebit.Waycheck.desktop
%{_datadir}/metainfo/dev.serebit.Waycheck.metainfo.xml
%{_datadir}/icons/hicolor/

%changelog
* Wed Feb 19 2025 Neal Gompa <ngompa@opensuse.org>
- Update to 1.6.0
  + Update upstream protocol list to v1.41
  + Add COSMIC A11y and AT-SPI protocols
  + Add ChromeOS aura-output-management protocol
  + Add Gamescope reshade protocol
  + Add Treeland protocols
  + Correct identifiers of KDE virtual desktop and external brightness protocols
  + Expand default window width to show all tabs
* Fri Dec 20 2024 Neal Gompa <ngompa@opensuse.org>
- Update to 1.5.0
  + Update upstream protocol list to v1.39
  + Add detection of COSMIC overlap notify protocol
  + Remove margins on tab view
  + Detect COSMIC protocols properly
* Sun Oct 13 2024 Neal Gompa <ngompa@opensuse.org>
- Update to 1.4.0
  + Add clarifying tooltips when compositor is unknown
  + Update upstream protocol list to v1.38
  + Add frog protocols 🐸
  + Add KDE external brightness protocol
  + Add additional keys to desktop file
* Thu Sep  5 2024 Neal Gompa <ngompa@opensuse.org>
- Update to 1.3.1
  + Fix detection of COSMIC protocols
* Sat Aug 31 2024 Neal Gompa <ngompa@opensuse.org>
- Update to 1.3.0
  + Add COSMIC protocols 🌌
  + Update upstream protocol list to v1.37
* Sun Apr 21 2024 Neal Gompa <ngompa@opensuse.org>
- Update to 1.2.1
  + Update "Upstream" protocol list to wayland-protocols v1.35
* Sat Mar 30 2024 Neal Gompa <ngompa@opensuse.org>
- Update to 1.2.0
  + Update "Upstream" protocol list to wayland-protocols v1.34
  + Add KDE "Screen edge" protocol
  + Add Gamescope protocols 🐸
  + Clean up Meson post-install script
* Fri Mar  1 2024 Neal Gompa <ngompa@opensuse.org>
- Update to v1.1.1
  + Make the tab widget frameless
  + Update branding colors in metainfo.xml
  + http -> https in some links in metainfo.xml
  + Add release URLs and additional release metadata in metainfo.xml
  + Clarify recommended display length and screenshot types in metainfo.xml
* Sat Feb 10 2024 Neal Gompa <ngompa@opensuse.org>
- Update to v1.1.0
  + Update protocol list to wayland-protocols v1.33
  + Add XDG Foreign v1
  + Add captions and environment info to screenshot metadata
  + Shorten app summary
  + Add missing interface for XDG Foreign v2
  + Fix aura-shell protocol detection
* Tue Jan 23 2024 Neal Gompa <ngompa@opensuse.org>
- Use GCC 11 for SLE/Leap
* Sun Oct 15 2023 Neal Gompa <ngompa@opensuse.org>
- Update to v1.0.0
  + Add a tab for ChromeOS protocols
  + Add a tab for unknown protocol interfaces
  + Add a search bar for quickly finding protocols
  + Add a combo box to filter by implemented or unimplemented protocols
  + Add explanatory tooltips to table headers
  + Fix detection of the virtual pointer manager protocol
  + Fix detection of the DRM lease protocol
  + Fix warning on startup from the Qt desktop filename
* Thu Sep 28 2023 Neal Gompa <ngompa@opensuse.org>
- Update to v0.2.0
  + Add KDE and Weston protocols
  + Use a tabbed view with separate tables for each protocol group
  + Fix contrast issues
  + Update icon
  + Prevent editing table cells
  + Only allow selecting one cell at a time
  + Fix icon not showing in window decorations on KDE Plasma
* Thu Sep 28 2023 Neal Gompa <ngompa@opensuse.org>
- Initial packaging based on Fedora package
